<?php
/**
 * @file
 * Contains administration form components and validation.
 */

/**
 * Function casetracker_nag_admin_display
 *
 * Creates all the necessary fields for the admin menu.
 *
 * @return
 *  Returns a formatted form ready for display.
 */
function casetracker_nag_admin_display() {
  $form = array();

  $form['casetracker_nag_autorole'] = array(
    '#type' => 'fieldset',
    '#title' => t('Auto Assign Role'),
    '#collapsible' => TRUE,
    '#collapsed' => FALSE,
  );

  // Grab all role names

  $casetracker_nag_admin_roles_query = db_query('SELECT name FROM {role}');

  while ($casetracker_nag_admin_roles_results = db_fetch_array($casetracker_nag_admin_roles_query)) {
    $casetracker_nag_admin_roles_final[$casetracker_nag_admin_roles_results['name']] = $casetracker_nag_admin_roles_results['name'];
  }

  // avoid calling the function twice
  $casetracker_nag_admin_cases = casetracker_realm_load('status');

  $form['casetracker_nag_autorole']['casetracker_nag_autorole_val'] = array(
    '#type' => 'select',
    '#title' => t('Roles'),
    '#default_value' => variable_get('casetracker_nag_autorole_val', 'authenticated user'),
    '#options' => $casetracker_nag_admin_roles_final,
    '#description' => t('Select a role from the list'),
  );

  $form['casetracker_nag_closestate'] = array(
    '#type' => 'fieldset',
    '#title' => t('Close State'),
    '#collapsible' => TRUE,
    '#collapsed' => FALSE,
  );

  // initial state for autoclose to run
  $form['casetracker_nag_closestate']['casetracker_nag_autoclose_initialstate'] = array(
    '#type' => 'select',
    '#title' => t('Auto Close State'),
    '#default_value' => variable_get('casetracker_nag_autoclose_initialstate', ''),
    '#options' => $casetracker_nag_admin_cases,
    '#description' => t('Select the state tickets should be in before they are automatically closed'),
  );

  // state to put cases in when autoclose has run
  $form['casetracker_nag_closestate']['casetracker_nag_autoclose_closestate'] = array(
    '#type' => 'select',
    '#title' => t('Close State'),
    '#default_value' => variable_get('casetracker_nag_autoclose_closestate', ''),
    '#options' => $casetracker_nag_admin_cases,
    '#description' => t('Select the state tickets should be put into when automatically closed'),
  );

  $form['casetracker_nag_closestate']['casetracker_nag_autoclose_closetime'] = array(
    '#type' => 'textfield',
    '#title' => t('Days before closing'),
    '#default_value' => variable_get('casetracker_nag_autoclose_closetime', 0),
    '#size' => 5,
    '#maxlength' => 5,
    '#required' => TRUE,
    '#description' => t('Number of days before a ticket can be auto closed'),
  );

  return system_settings_form($form);
}

/**
 * Function casetracker_nag_admin_display_validate
 *
 * Validation hook for the administration form
 *
 * @param $form
 *  The form as passed in
 * @param $form_state
 *  The current state of the form including results
 */

function casetracker_nag_admin_display_validate($form, &$form_state) {
  // $form_state['values']['role'] defined by casetracker module
  if ($form_state['values']['role'] == 'anonymous user') {
    form_set_error('', t('Please choose a role other than anonymous'));
  }
}
